QUESTIONS = {
    "Q01" : ['''Makes lists''', '''Relies on memory'''],
    "Q02" : ['''Sceptical''', '''Wants to believe'''],
    "Q03" : ['''Bored by time alone''', '''Needs time alone'''],
    "Q04" : ['''Accepts things as they are''', '''Unsatisfied with the ways things are'''],
    "Q05" : ['''Keeps a clean room''', '''Just puts stuff where ever'''],
    "Q06" : ['''Thinks "robotic" is an insult''', '''Strives to have a mechanical mind'''],
    "Q07" : ['''Energetic''', '''Mellow'''],
    "Q08" : ['''Prefer to take multiple choice test''', '''Prefer essay answers'''],
    "Q09" : ['''Chaotic''', '''Organized'''],
    "Q10" : ['''Easily hurt''', '''Thick-skinned'''],
    "Q11" : ['''Works best in groups''', '''Works best alone'''],
    "Q12" : ['''Focused on the present''', '''Focused on the future'''],
    "Q13" : ['''Plans far ahead''', '''Plans at the last minute'''],
    "Q14" : ['''Wants people's respect''', '''Wants their love'''],
    "Q15" : ['''Gets worn out by parties''', '''Gets fired up by parties'''],
    "Q16" : ['''Fits in''', '''Stands out'''],
    "Q17" : ['''Keeps options open''', '''Commits'''],
    "Q18" : ['''Wants to be good at fixing things''', '''Wants to be good at fixing people'''],
    "Q19" : ['''Talks more''', '''Listens more'''],
    "Q20" : ['''When describing an event, will tell people what happened''', '''When describing an event, will tell people what it meant'''],
    "Q21" : ['''Gets work done right away''', '''Procrastinates'''],
    "Q22" : ['''Follows the heart''', '''Follows the head'''],
    "Q23" : ['''Stays at home''', '''Goes out on the town'''],
    "Q24" : ['''Wants the big picture''', '''Wants the details'''],
    "Q25" : ['''Improvises''', '''Prepares'''],
    "Q26" : ['''Bases morality on justice''', '''Bases morality on compassion'''],
    "Q27" : ['''Finds it difficult to yell very loudly''', '''Yelling to others when they are faraway comes naturally'''],
    "Q28" : ['''Theoretical''', '''Empirical'''],
    "Q29" : ['''Works hard''', '''Plays hard'''],
    "Q30" : ['''Uncomfortable with emotions''', '''Values emotions'''],
    "Q31" : ['''Likes to perform in front of other people''', '''Avoids public speaking'''],
    "Q32" : ['''Likes to know "Who?", "What?", "When?"''', '''Likes to know "Why?"''']
}



QUESTIONS_KR = {
    "Q01": ["목록을 만든다", "기억에 의존한다"],
    "Q02": ["회의적이다", "믿고 싶어 한다"],
    "Q03": ["혼자 있으면 지루하다", "혼자 있는 시간이 필요하다"],
    "Q04": ["있는 그대로 받아들인다", "현실에 만족하지 않는다"],
    "Q05": ["방을 깨끗하게 유지한다", "물건을 아무 데나 둔다"],
    "Q06": ["'기계적이다'는 말이 모욕처럼 느껴진다", "기계적인 사고를 추구한다"],
    "Q07": ["에너지가 넘친다", "차분하다"],
    "Q08": ["객관식 시험을 선호한다", "서술형을 선호한다"],
    "Q09": ["혼란스럽다", "정돈되어 있다"],
    "Q10": ["상처를 쉽게 받는다", "둔감한 편이다"],
    "Q11": ["여럿과 함께 일할 때 가장 잘한다", "혼자 일할 때 가장 잘한다"],
    "Q12": ["현재에 집중한다", "미래에 집중한다"],
    "Q13": ["먼저 계획을 세워둔다", "막판에 계획한다"],
    "Q14": ["사람들의 존중을 원한다", "사람들의 사랑을 원한다"],
    "Q15": ["파티에 가면 쉽게 지친다", "파티가 에너지를 준다"],
    "Q16": ["주변에 잘 섞인다", "두드러지는 편이다"],
    "Q17": ["옵션을 열어 둔다", "결단하고 확정하는 편이다"],
    "Q18": ["물건을 잘 고치는 사람이 되고 싶다", "사람을 잘 돌보는 사람이 되고 싶다"],
    "Q19": ["말을 더 많이 한다", "듣는 편이 더 많다"],
    "Q20": ["일어난 일을 중심으로 설명한다", "그 일이 의미하는 바를 중심으로 설명한다"],
    "Q21": ["일을 바로 처리한다", "미루는 편이다"],
    "Q22": ["마음을 따른다", "머리(이성)를 따른다"],
    "Q23": ["집에 머무는 것을 좋아한다", "외출해 돌아다니는 것을 좋아한다"],
    "Q24": ["큰 그림을 알고 싶어 한다", "세부 사항을 알고 싶어 한다"],
    "Q25": ["즉흥적으로 한다", "미리 준비한다"],
    "Q26": ["정의를 기준으로 도덕을 판단한다", "연민을 기준으로 도덕을 판단한다"],
    "Q27": ["크게 소리치기 어렵다", "멀리 있는 사람에게도 자연스럽게 소리칠 수 있다"],
    "Q28": ["이론적이다", "경험적이다"],
    "Q29": ["열심히 일한다", "열심히 논다"],
    "Q30": ["감정을 다루는 것이 불편하다", "감정을 중요하게 여긴다"],
    "Q31": ["사람들 앞에서 공연하기를 좋아한다", "사람들 앞에서 말하는 것을 피한다"],
    "Q32": ["'누가', '무엇을', '언제'가 궁금하다", "'왜'가 궁금하다"]
}




