OEJTS_INFO = """Open Extended Jungian Type Scales 1.2


Introduction

This is a personality test that will give you a result equivalent to the Myers-Briggs Type Indicator, although this test is not the MBTI and has no affiliation with it.


Instructions

On each page, there are 32 pairs of personality descriptions connected by a five point scale. For each pair, you must choose where on the scale between them you think you are. For example, if the pair is “angry” versus “calm”, you should choose far left on the scale if you are always angry and never calm, a middle if you are half and half, etc.


Licence

The items of the Open Extended Jungian Type Scales 1.2 are licenced under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. The OEJTS come with no guarantees of reliability or accuracy of any kind.


For more information, visit https://openpsychometrics.org/tests/OJTS/development/"""





OEJTS_INFO_KR = """Open Extended Jungian Type Scales 1.2


소개

이 검사는 마이어스-브릭스 유형 지표(MBTI)와 유사한 결과를 제공하는 성격 검사입니다. 다만 이 검사는 MBTI 자체가 아니며, MBTI와 어떠한 공식적인 관련도 없습니다.

검사 방법

각 페이지에는 다섯 단계 척도로 연결된 32개의 성격 묘사 쌍이 제시됩니다. 각 쌍을 읽고, 두 특성 사이에서 자신이 가장 가깝다고 생각되는 위치를 선택하면 됩니다.
예를 들어, 제시된 쌍이 “화를 잘 내는 편”과 “차분한 편”일 때, 늘 화를 내고 거의 차분하지 않으면 척도의 가장 왼쪽을 선택하고, 두 성향이 비슷하다면 가운데를 선택하는 식입니다.

라이선스

Open Extended Jungian Type Scales 1.2의 문항은 Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License의 적용을 받습니다.
OEJTS는 신뢰도나 정확성에 대해 어떤 보증도 제공하지 않습니다.

자세한 정보는 https://openpsychometrics.org/tests/OJTS/development/ 를 방문하십시오."""

